import json
import re
import requests
from bs4 import BeautifulSoup


def get_urls(page_no):
    '''Iterate over EnergyStar search results by page and get links to individual datasets'''
    # TODO: Make this with params
    BASE_URL='https://data.energystar.gov/browse/embed?category=Active+Specifications&limitTo=datasets&page='

    page_url = '%s%s' % (BASE_URL, page_no)
    response = requests.get(page_url)

    soup = BeautifulSoup(response.content, 'html.parser')

    results = soup.findAll('a', {'class': 'name'})

    links = []
    for r in results:
        links.append(r['href'])
    return links


def get_api_links(url_list):
    '''Taking a list of urls of individual EnergyStar datasets, get each and
    scrape the api url from javascript tag'''
    api_links = []

    for url in url_list:
        response = requests.get(url)
        soup = BeautifulSoup(response.content, 'html.parser')
        script_tag = soup.find(string=re.compile('initialState'))
        exp = re.compile(r'https://data.energystar.gov/resource/[\w\-_]+.json')
        pull = re.search(exp, script_tag.string)
        if pull:
            api_links.append(pull.group(0))
    return api_links


def get_database_json(api_url):
    '''Use requests to get the json and write to a file with its db identifier
    or name'''
    response = requests.get(api_url)
    filename = (re.search(r'(?<=resource/).+$', api_url)).group(0)
    with open(str(filename), 'w') as f:
        try:
            f.write(json.dumps(response.json()))
        except json.decoder.JSONDecodeError:
            print(api_url)
            print(filename)

for i in range(1, 6):
    url_list = get_urls(i)
    api_urls = get_api_links(url_list)
    for api_url in api_urls:
        get_database_json(api_url)
